@@ -1,3 +1,5 @@
+from dataclasses import dataclass
+
 def _is(a, b):
     return a is b
 
@@ -91,12 +93,33 @@ def _if_exp(t,b,o):
 def _subscript(a, b):
     return a[b]
 
+@dataclass
+class Starred:
+    def __init__(self, a):
+        self.value = a
+
+def _starred(a):
+    return Starred(a)
+
 def _list(*args):
-    return args
+    l = []
+    for arg in args:
+        if isinstance(arg, Starred):
+            l.extend(arg.value)
+        else:
+            l.append(arg)
+            
+    return l
 
 def _tuple(*args):
-    return tuple(args)
+    return args
 
 def _dict(*args):
-    n = len(args)/2
-    return {k: v for k, v in zip(args[:n], args[n:])}
+    n = int(len(args)/2)
+    obj = {}
+    for k, v in zip(args[:n], args[n:]):
+        if k is None:
+            obj.update(v)
+        else:
+            obj[k] = v
+    return obj
